#!/usr/local/tcl8.4/bin/tclsh8.4
#
# watchHttp.tcl
# Copyright (c) 2005, Todd J Martin
#
#  This is an example of how to capture and examine http packets

set dirname [file dirname [info script]]
set dirname [file join $dirname ..]
lappend auto_path $dirname
package require Pcap

puts "Pcap [package present Pcap]"

proc rawDump {str} {
    set out ""
    for {set cnt 0} {$cnt < [string length $str]} {incr cnt} {
        binary scan [string index $str $cnt] c dec
        set dec [expr ( $dec + 0x100 ) % 0x100]
        append out [format "%x " $dec]
    }
    puts $out
}

proc getPacket {p} {
    set packet [pcap::getPacket $p]
    set data [lindex $packet 1]
    set tcpPacket [string range $data 34 end]
    binary scan [string index $tcpPacket 12] h2 tcpHeadLen
    set tcpHeadLen "0x$tcpHeadLen"
    set tcpHeadLen [expr {$tcpHeadLen * 4}]
    if {$tcpHeadLen >= [string length $tcpPacket]} {
	return
    }
    set tcpData [string range $tcpPacket $tcpHeadLen end]
    if {![binary scan $tcpData A* httpText] || ![string length $httpText]} {
	return 
    }
    set httpCode [string range $httpText 0 [expr [string first " " $httpText] - 1]]
    switch -glob -- $httpCode {
	"GET" {
	    set i1 [expr [string first " " $httpText] + 1]
	    set i2 [expr [string first " " $httpText $i1] - 1]
	    set url [string range $httpText $i1 $i2]
	    puts "$httpCode $url"
	}
	"HTTP*" {
	    set i1 [expr [string first " " $httpText] + 1]
	    set i2 [expr [string first "\r" $httpText $i1] - 1]
	    set responseCode [string range $httpText $i1 $i2]
	    puts "$httpCode $responseCode"
	}
	default {
	}
    }
}

set p [pcap::pcap_open -filter "ip proto \\tcp and port 80" [pcap::lookupdev]]
if {[lindex [pcap::datalink $p] 1] != "Ethernet"} {
    puts "Don't understand this datalink type"
    close $p
    exit
}

fconfigure $p -encoding binary -translation binary
fileevent $p readable "getPacket $p"
vwait forever
