[manpage_begin tclPcap n 2.0.0]
[copyright {2001-2005 by Todd J Martin <todd.martin@acm.org>}]
[moddesc {A Tcl interface to the pcap packet capture library}]
[titledesc {Interface to the PCAP library}]
[require Tcl 8.0]
[require Pcap 2.0.0]

[description]

tclPcap is a set of Tcl commands that provide an interface to the pcap packet
capture library, available on  a  wide  variety  of  platforms.  This
extension  does this by creating a new channel type called pcap.  This allows
for very easy access to the  library.   All  new  commands added to the
interpreter are in the pcap:: namespace.

[list_begin definitions]

[call [cmd pcap_open] [opt [arg -offline]] [opt [arg -nopromisc]] \
    [opt [arg "-caplength length"]] [opt [arg "-filter filter"]] [arg fileName|deviceName]]

Creates a new channel that can be used to read captured packets.  This command
returns the name of the new channel.  


[list_begin definitions]

[lst_item -offline]
The  [arg -offline] flag  indicates that data  will not be captured from a
network device.  Instead, a file name will be given that is the name of  a
capture file to read.  This capture file could have been created by tclpcap or
tcpdump (or any other program that uses libpcap).  

[lst_item -nopromisc]
The  [arg -nopromisc]  tells tclpcap not to open the capture device in
promiscuous mode.  The option has  no  effect  if  [arg -offline]  is given.   

[lst_item "-caplength length"]
The [arg -caplength] option specifies the number of bytes of each frame to
capture.  The default value is 1500.  If  a  negative  number is given, the
default value will be used.  

[lst_item "-filter filter"]
The [arg -filter] specifies a filter string that is to be set for this
capture.  The syntax of the filter is as documented in the tcpdump man page.
If no filter is specified, the string "default" is used, which will capture
all packets on the network.  If the filter cannot be applied to the capture
device, pcap_open will throw an error.

[lst_item "fileName|deviceName"]
The last argument is the name of the network  device  to capture  from, unless
[arg -offline] has been given.  In that case it is the name of a capture file
to read from.  The special deviceName  of  "any" will cause all network
interfaces to be used for captures.

[list_end]


[call [cmd lookupdev]]

This  calls  pcap_lookupdev  and  returns  the name of a network device that
can be used with [fun pcap_open].  The loopback  interface is  ignored,  and  the
lowest numbered unit is the one returned (assuming multiple devices).

[call [cmd lookupnet] [arg deviceName]]

This calls pcap_lookupnet with the supplied network deviceName.  The command
returns a list containing the network address as the first element and the
netmask as the second element.

[call [cmd getPacket] [arg pcapChannel]]

This command takes the name of a [arg pcapChannel] that was opened with
[fun pcap_open] as an argument.  It reads the next available packet and returns
that in a list.  The first element of the list is a header containing
the timestamp and length of the packet.  The next element is the actual data
itself.   The data is a binary string, so it is not useful to print it
out.  See [fun packetToString] and [fun printPacket].

[nl]

It is possible for [fun getPacket] to be unable to read a packet.  In this
case, an empty list will be returned.  The caller should not interpret this to
mean that an end of file has been reached (if reading offline) or that the
network interface is down.  The [fun eof] command should be used to detect
this.  Am empty list could be returned even if the channel is in blocking
mode.

[call [cmd packetToString] [arg packet]]

This command takes a [arg packet], as returned from [fun getPacket],  as an
argument and returns the captured data as a string.

[call [cmd printPacket] [arg packet]]

This command takes a [arg packet], as returned from [fun getPacket], as an argument and
prints the hex values to stdout.

[call [cmd savefile] [arg pcapChannel] [opt [arg on|off]]]

This turns on or off the dumping of the captured  packets  to  a file.   The
name of the capture file is configured through [fun fconfigure] with the 
[arg -savefile] option.  If neither on nor off are specified, then the current
state is returned.

[call [cmd datalink] [arg pcapChannel]]

This calls pcap_datalink which returns the link layer type of the
[arg pcapChannel].  The return value is a list.  The first element of the list is
a string representing the name of the datalink.  This corresponds to what is
listed in the pcap man page.  E.g., DLT_EN10MB.  The second element of the
list is a longer version of the datalink that is more human readable.  E.g.,
Ethernet.

[call [cmd dump_open] [arg pcapChannel] [arg dumpFileName]]

[call [cmd dump] [arg pcap_dumper] [arg packet]]

[call [cmd dump_close] [arg pcap_dumper]]

[call [cmd version]]

This calls pcap_lib_version which returns a string containing version
information of the pcap library.

[list_end]

[section {CONFIGURATION OPTIONS}]

The [fun fconfigure] command can be used to query and modify several
parameters of the channel created by [fun pcap_open].

[list_begin definitions]

[lst_item [arg "-savefile fileName"]]

The [arg -savefile] option specifies the name of a file that is to be used to
save dumped packets to.  This option does not actually start dumping data to
the file.  The [fun savefile] command needs to be called to start saving
captured packets.

[nl]

Attempts to change the [arg -savefile] while packets are being dumped will result in
an error.

[nl]

The value of [arg -savefile] defaults to an empty string.

[lst_item [arg "-filter filter"]]

The [arg -filter] option allows the filter used by pcap to be changed.  This
option corresponds to the [arg -filter] option of the [fun pcap_open] command.
By default, the filter captures all packets.

[list_end]

[section {EXAMPLE}]
[section {LIMITATIONS}]
[see_also tcpdump pcap(3) fconfigure(n)]
[manpage_end]
